@@ -1,4 +1,4 @@
-# Time-stamp: <2015-12-22 11:55:15 Tao Liu>
+# Time-stamp: <2016-02-15 16:12:30 Tao Liu>
 
 """Description: MACS 2 main executable
 
@@ -23,6 +23,7 @@ import os
 import sys
 import logging
 from time import strftime
+import tempfile
 
 # ------------------------------------
 # own python modules
@@ -60,16 +61,18 @@ def run( args ):
     error = options.error
     #0 output arguments
     info("\n"+options.argtxt)
-    options.PE_MODE = options.format in ('BAMPE',)
+    options.PE_MODE = options.format in ('BAMPE','BEDPE')
     if options.PE_MODE: tag = 'fragment' # call things fragments not tags
     else: tag = 'tag'
-    
+
+    tempfile.tempdir = options.tempdir
+
     #1 Read tag files
     info("#1 read %s files...", tag)
     if options.PE_MODE: (treat, control) = load_frag_files_options (options)
     else:       (treat, control) = load_tag_files_options  (options)
     if control is not None: check_names(treat, control, error)
-    
+
     info("#1 %s size = %d", tag, options.tsize)
     tagsinfo  = "# %s size is determined as %d bps\n" % (tag, options.tsize)
     
